You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by eh...@apache.org on 2007/03/01 07:24:59 UTC

svn commit: r513173 - /incubator/wicket/branches/wicket-1.x/wicket-spring-annot/src/main/java/wicket/spring/injection/annot/SpringComponentInjector.java

Author: ehillenius
Date: Wed Feb 28 22:24:58 2007
New Revision: 513173

URL: http://svn.apache.org/viewvc?view=rev&rev=513173
Log:
WICKET-337

Modified:
    incubator/wicket/branches/wicket-1.x/wicket-spring-annot/src/main/java/wicket/spring/injection/annot/SpringComponentInjector.java

Modified: incubator/wicket/branches/wicket-1.x/wicket-spring-annot/src/main/java/wicket/spring/injection/annot/SpringComponentInjector.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/wicket-spring-annot/src/main/java/wicket/spring/injection/annot/SpringComponentInjector.java?view=diff&rev=513173&r1=513172&r2=513173
==============================================================================
--- incubator/wicket/branches/wicket-1.x/wicket-spring-annot/src/main/java/wicket/spring/injection/annot/SpringComponentInjector.java (original)
+++ incubator/wicket/branches/wicket-1.x/wicket-spring-annot/src/main/java/wicket/spring/injection/annot/SpringComponentInjector.java Wed Feb 28 22:24:58 2007
@@ -17,7 +17,6 @@
 package wicket.spring.injection.annot;
 
 import java.io.FileNotFoundException;
-import java.io.Serializable;
 
 import javax.servlet.ServletContext;
 
@@ -30,6 +29,7 @@
 import org.springframework.web.context.support.WebApplicationContextUtils;
 
 import wicket.Application;
+import wicket.IClusterable;
 import wicket.MetaDataKey;
 import wicket.Session;
 import wicket.application.IComponentInstantiationListener;
@@ -144,7 +144,7 @@
 	 * This is a holder for the application context. The reason we need a holder
 	 * is that metadata only supports storing serializable objects but
 	 * application context is not. The holder acts as a serializable wrapper for
 	 * the context. Notice that although holder implements serializable it
 	 * really is not because it has a reference to non serializable context -
 	 * but this is ok because metadata objects in application are never
 	 * serialized.
@@ -152,7 +152,7 @@
 	 * @author ivaynberg
 	 * 
 	 */
-	private static class ApplicationContextHolder implements Serializable {
+	private static class ApplicationContextHolder implements IClusterable {
 		private static final long serialVersionUID = 1L;
 
 		private final ApplicationContext context;
@@ -144,7 +144,7 @@
 	 * is that metadata only supports storing serializable objects but
 	 * application context is not. The holder acts as a serializable wrapper for
-	 * the context. Notice that although holder implements serializable it
+	 * the context. Notice that although holder implements IClusterable it
 	 * really is not because it has a reference to non serializable context -
 	 * but this is ok because metadata objects in application are never